# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/cronomaxrf',
                'doc_host': 'https://fligt.github.io',
                'git_url': 'https://github.com/fligt/cronomaxrf',
                'lib_path': 'cronomaxrf'},
  'syms': { 'cronomaxrf.crono': { 'cronomaxrf.crono._get_attrs': ( 'exploring-the-crono-ma-xrf-hdf5-file-format.html#_get_attrs',
                                                                   'cronomaxrf/crono.py'),
                                  'cronomaxrf.crono._nesting': ( 'exploring-the-crono-ma-xrf-hdf5-file-format.html#_nesting',
                                                                 'cronomaxrf/crono.py'),
                                  'cronomaxrf.crono.peek_inside': ( 'exploring-the-crono-ma-xrf-hdf5-file-format.html#peek_inside',
                                                                    'cronomaxrf/crono.py'),
                                  'cronomaxrf.crono.read_datasets': ( 'exploring-the-crono-ma-xrf-hdf5-file-format.html#read_datasets',
                                                                      'cronomaxrf/crono.py'),
                                  'cronomaxrf.crono.report': ( 'exploring-the-crono-ma-xrf-hdf5-file-format.html#report',
                                                               'cronomaxrf/crono.py')},
            'cronomaxrf.data': { 'cronomaxrf.data._bar_progress': ('download-demo-data.html#_bar_progress', 'cronomaxrf/data.py'),
                                 'cronomaxrf.data._check_filehash': ('download-demo-data.html#_check_filehash', 'cronomaxrf/data.py'),
                                 'cronomaxrf.data.download': ('download-demo-data.html#download', 'cronomaxrf/data.py')},
            'cronomaxrf.gridify': {'cronomaxrf.gridify.gridify': ('gridify-by-selection.html#gridify', 'cronomaxrf/gridify.py')},
            'cronomaxrf.interpolation': { 'cronomaxrf.interpolation.convert_crono': ( 'interpolation-gymnastics.html#convert_crono',
                                                                                      'cronomaxrf/interpolation.py'),
                                          'cronomaxrf.interpolation.get_array': ( 'interpolation-gymnastics.html#get_array',
                                                                                  'cronomaxrf/interpolation.py'),
                                          'cronomaxrf.interpolation.tree': ( 'interpolation-gymnastics.html#tree',
                                                                             'cronomaxrf/interpolation.py')}}}
